@@ -13,13 +13,15 @@ namespace League\Uri;
 
 use GuzzleHttp\Psr7\Utils;
 use Nyholm\Psr7\Factory\Psr17Factory;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\Test;
 use PHPUnit\Framework\TestCase;
 use Psr\Http\Message\UriInterface as Psr7UriInterface;
 
-/**
- * @group modifier
- * @coversDefaultClass \League\Uri\BaseUri
- */
+#[CoversClass(BaseUri::class)]
+#[Group('modifier')]
 final class BaseUriTest extends TestCase
 {
     private const BASE_URI = 'http://a/b/c/d;p?q';
@@ -32,9 +34,7 @@ final class BaseUriTest extends TestCase
         );
     }
 
-    /**
-     * @dataProvider resolveProvider
-     */
+    #[DataProvider('resolveProvider')]
     public function testCreateResolve(string $baseUri, string $uri, string $expected): void
     {
         $uriResolved = BaseUri::from($baseUri)->resolve($uri);
@@ -100,9 +100,7 @@ final class BaseUriTest extends TestCase
         self::assertEquals($uri, BaseUri::from('https://example.com/path')->relativize($uri)->getUriString());
     }
 
-    /**
-     * @dataProvider relativizeProvider
-     */
+    #[DataProvider('relativizeProvider')]
     public function testRelativize(string $uri, string $resolved, string $expected): void
     {
         self::assertSame(
@@ -154,9 +152,7 @@ final class BaseUriTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider relativizeAndResolveProvider
-     */
+    #[DataProvider('relativizeAndResolveProvider')]
     public function testRelativizeAndResolve(
         string $baseUri,
         string $uri,
@@ -187,10 +183,9 @@ final class BaseUriTest extends TestCase
     }
 
     /**
-     * @dataProvider uriProvider
-     *
      * @param array<bool> $infos
      */
+    #[DataProvider('uriProvider')]
     public function testInfo(
         Psr7UriInterface|Uri $uri,
         Psr7UriInterface|Uri|null $base_uri,
@@ -263,9 +258,7 @@ final class BaseUriTest extends TestCase
         self::assertTrue(BaseUri::from('example.com#foobar')->isRelativePath());
     }
 
-    /**
-     * @dataProvider sameValueAsProvider
-     */
+    #[DataProvider('sameValueAsProvider')]
     public function testSameValueAs(Psr7UriInterface|Uri $uri1, Psr7UriInterface|Uri $uri2, bool $expected): void
     {
         self::assertSame($expected, BaseUri::from($uri2)->isSameDocument($uri1));
@@ -322,9 +315,7 @@ final class BaseUriTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider getOriginProvider
-     */
+    #[DataProvider('getOriginProvider')]
     public function testGetOrigin(Psr7UriInterface|Uri|string $uri, ?string $expectedOrigin): void
     {
         self::assertSame($expectedOrigin, BaseUri::from($uri)->origin()?->__toString());
@@ -369,12 +360,14 @@ final class BaseUriTest extends TestCase
                 'uri' => Uri::new('https://0:443/'),
                 'expectedOrigin' => 'https://0.0.0.0',
             ],
+            'compressed ipv6' => [
+                'uri' => 'https://[1050:0000:0000:0000:0005:0000:300c:326b]:443/',
+                'expectedOrigin' => 'https://[1050::5:0:300c:326b]',
+            ],
         ];
     }
 
-    /**
-     * @dataProvider getCrossOriginExamples
-     */
+    #[DataProvider('getCrossOriginExamples')]
     public function testIsCrossOrigin(string $original, string $modified, bool $expected): void
     {
         self::assertSame($expected, BaseUri::from($original)->isCrossOrigin($modified));
@@ -403,9 +396,7 @@ final class BaseUriTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider resolveProvider
-     */
+    #[DataProvider('resolveProvider')]
     public function testResolveWithPsr7Implementation(string $baseUri, string $uri, string $expected): void
     {
         $resolvedUri = BaseUri::from(Utils::uriFor($baseUri))->resolve($uri);
@@ -414,9 +405,7 @@ final class BaseUriTest extends TestCase
         self::assertSame($expected, (string) $resolvedUri);
     }
 
-    /**
-     * @dataProvider relativizeProvider
-     */
+    #[DataProvider('relativizeProvider')]
     public function testRelativizeWithPsr7Implementation(string $uriString, string $resolved, string $expected): void
     {
         $uri = Utils::uriFor($uriString);
@@ -436,9 +425,7 @@ final class BaseUriTest extends TestCase
         self::assertSame($expected, (string) $relativizeUri);
     }
 
-    /**
-     * @dataProvider getOriginProvider
-     */
+    #[DataProvider('getOriginProvider')]
     public function testGetOriginWithPsr7Implementation(Psr7UriInterface|Uri|string $uri, ?string $expectedOrigin): void
     {
         $origin = BaseUri::from(Utils::uriFor((string) $uri), new \GuzzleHttp\Psr7\HttpFactory())->origin();
@@ -452,9 +439,7 @@ final class BaseUriTest extends TestCase
         self::assertSame($expectedOrigin, $origin);
     }
 
-    /**
-     * @dataProvider provideIDNUri
-     */
+    #[DataProvider('provideIDNUri')]
     public function testHostIsIDN(string $uri, bool $expected): void
     {
         self::assertSame($expected, BaseUri::from($uri)->hasIdn());
@@ -489,7 +474,7 @@ final class BaseUriTest extends TestCase
         ];
     }
 
-    /** @dataProvider unixpathProvider */
+    #[DataProvider('unixpathProvider')]
     public function testReturnsUnixPath(?string $expected, string $input): void
     {
         self::assertSame($expected, BaseUri::from($input)->unixPath());
@@ -505,11 +490,11 @@ final class BaseUriTest extends TestCase
             ],
             'absolute path' => [
                 'expected' => '/path',
-                'inout' => 'file:///path',
+                'input' => 'file:///path',
             ],
             'path with empty char' => [
                 'expected' => '/path empty/bar',
-                'inout' => 'file:///path%20empty/bar',
+                'input' => 'file:///path%20empty/bar',
             ],
             'relative path with dot segments' => [
                 'expected' => 'path/./relative',
@@ -526,7 +511,7 @@ final class BaseUriTest extends TestCase
         ];
     }
 
-    /** @dataProvider windowLocalPathProvider */
+    #[DataProvider('windowLocalPathProvider')]
     public function testReturnsWindowsPath(?string $expected, string $input): void
     {
         self::assertSame($expected, BaseUri::from($input)->windowsPath());
@@ -575,7 +560,7 @@ final class BaseUriTest extends TestCase
         ];
     }
 
-    /** @dataProvider rfc8089UriProvider */
+    #[DataProvider('rfc8089UriProvider')]
     public function testReturnsRFC8089UriString(?string $expected, string $input): void
     {
         self::assertSame($expected, BaseUri::from($input)->toRfc8089());
@@ -603,4 +588,44 @@ final class BaseUriTest extends TestCase
             ],
         ];
     }
+
+    #[DataProvider('opaqueUriProvider')]
+    #[Test]
+    public function it_tells_if_an_uri_is_opaque(bool $expected, string $uri): void
+    {
+        self::assertSame($expected, BaseUri::from($uri)->isOpaque());
+    }
+
+    public static function opaqueUriProvider(): iterable
+    {
+        yield 'empty URI' => [
+            'expected' => false,
+            'uri' => '',
+        ];
+
+        yield 'relative URI' => [
+            'expected' => false,
+            'uri' => 'path?query#fragment',
+        ];
+
+        yield 'URI with authority' => [
+            'expected' => false,
+            'uri' => '//authority/path?query#fragment',
+        ];
+
+        yield 'absolute HTTP URI' => [
+            'expected' => false,
+            'uri' => 'https://authority/path?query#fragment',
+        ];
+
+        yield 'absolute mail URI' => [
+            'expected' => true,
+            'uri' => 'mail:foo@example.com',
+        ];
+
+        yield 'data URI' => [
+            'expected' => true,
+            'uri' => 'data:',
+        ];
+    }
 }
